@@ -1,8 +1,8 @@
 /*
-  $Id: BestArray.h 13480 2011-10-27 15:21:26Z sloot $
+  $Id: BestArray.h 15264 2012-10-10 10:13:54Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/BestArray.h $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -26,8 +26,8 @@
   or send mail to:
       timbl@uvt.nl
 */
-#ifndef BESTARRAY_H
-#define BESTARRAY_H
+#ifndef TIMBL_BESTARRAY_H
+#define TIMBL_BESTARRAY_H
 
 #include "timbl/XMLtools.h"
 #include "timbl/neighborSet.h"
@@ -69,4 +69,4 @@ namespace Timbl {
   };
 
 }
-#endif //  BESTARRAY_H
+#endif // TIMBL_BESTARRAY_H
