@@ -1,8 +1,8 @@
 /*
-  $Id: Common.h 12969 2011-08-24 14:00:22Z sloot $
+  $Id: Common.h 15264 2012-10-10 10:13:54Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/Common.h $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -26,8 +26,8 @@
   or send mail to:
       timbl@uvt.nl
 */
-#ifndef COMMON_H
-#define COMMON_H
+#ifndef TIMBL_COMMON_H
+#define TIMBL_COMMON_H
 
 #include <iostream>
 #include <cmath>
