@@ -1,8 +1,8 @@
 /*
-  $Id: Instance.h 9981 2011-05-16 11:13:30Z sloot $
+  $Id: Instance.h 15266 2012-10-10 11:00:27Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/Instance.h $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -26,8 +26,8 @@
   or send mail to:
       timbl@uvt.nl
 */
-#ifndef INSTANCE_H
-#define INSTANCE_H
+#ifndef TIMBL_INSTANCE_H
+#define TIMBL_INSTANCE_H
 
 #include <stdexcept>
 #include <list>
@@ -35,9 +35,9 @@
 #include <map>
 #include "timbl/MsgClass.h"
 #include "timbl/Matrices.h"
+#include "ticcutils/TreeHash.h"
 
 namespace Timbl {
-  using Hash::StringHash;
   
   enum FeatVal_Stat { Unknown, Singleton, SingletonNumeric, NumericValue,
 		      NotNumeric };
@@ -58,8 +58,8 @@ namespace Timbl {
     std::ostream& put( std::ostream& ) const;
     const TargetValue *Value() const { return value; };
     void Value( const TargetValue *t ){  value = t; };
-    int Freq() const { return frequency; };
-    void IncFreq() {  frequency += 1; };
+    size_t Freq() const { return frequency; };
+    void IncFreq( int inc=1 ) {  frequency += inc; };
     void AddFreq( int f ) {  frequency += f; weight += f; };
     void DecFreq() {  frequency -= 1; };
     double Weight() const { return weight; };
@@ -67,7 +67,7 @@ namespace Timbl {
     size_t Index();
   protected:
     const TargetValue *value;
-    int frequency;
+    size_t frequency;
     double weight;
   private:
     Vfield& operator=( const Vfield& );
@@ -95,17 +95,16 @@ namespace Timbl {
     dist_iterator end() const { return distribution.end(); };
     virtual const TargetValue* BestTarget( bool &, bool = false ) const;
     void Merge( const ValueDistribution& );
-    virtual void SetFreq( const TargetValue *, const int, const double=1.0 );
-    virtual bool IncFreq( const TargetValue *, const double=1.0 );
+    virtual void SetFreq( const TargetValue *, int, double=1.0 );
+    virtual bool IncFreq( const TargetValue *, size_t, double=1.0 );
     void DecFreq( const TargetValue * );
     static ValueDistribution *read_distribution( std::istream &, 
-						  Target *, bool );
+						 Target *, bool );
     static ValueDistribution *read_distribution_hashed( std::istream &, 
 							Target *, bool );
     const std::string DistToString() const;
     const std::string DistToStringW( int ) const;
     double Confidence( const TargetValue * ) const;
-    virtual const std::string ToEncodedString() const;
     virtual const std::string SaveHashed() const;
     virtual const std::string Save() const;
     bool ZeroDist() const { return total_items == 0; };
@@ -113,7 +112,6 @@ namespace Timbl {
     ValueDistribution *to_VD_Copy( ) const;
     virtual WValueDistribution *to_WVD_Copy() const;
   protected:
-    virtual void DistToEncodedString( std::string& ) const;
     virtual void DistToString( std::string&, double=0 ) const;
     virtual void DistToStringWW( std::string&, int ) const;
     const TargetValue* BestTargetN( bool &, bool = false ) const;
@@ -128,8 +126,8 @@ namespace Timbl {
   public:
     WValueDistribution(): ValueDistribution() {};
     const TargetValue* BestTarget( bool &, bool = false ) const;
-    void SetFreq( const TargetValue *, const int, const double );
-    bool IncFreq( const TargetValue *, const double );
+    void SetFreq( const TargetValue *, int, double );
+    bool IncFreq( const TargetValue *, size_t, double );
     WValueDistribution *to_WVD_Copy( ) const;
     const std::string SaveHashed() const;
     const std::string Save() const;
@@ -138,7 +136,6 @@ namespace Timbl {
     void Normalize_2();
     void MergeW( const ValueDistribution&, double );
   private:
-    void DistToEncodedString( std::string& ) const;
     void DistToString( std::string&, double=0 ) const;
     void DistToStringWW( std::string&, int ) const;
     WValueDistribution *clone() const { 
@@ -147,7 +144,7 @@ namespace Timbl {
 
   class ValueClass {
   public:
-    ValueClass( const std::string& n, unsigned int i ):
+    ValueClass( const std::string& n, size_t i ):
       name( n ), index( i ), Frequency( 1 ) {};
     virtual ~ValueClass() {};
     void ValFreq( size_t f ){ Frequency = f; };
@@ -155,12 +152,12 @@ namespace Timbl {
     size_t ValFreq( ) const { return Frequency; };
     void incr_val_freq(){ Frequency++; };
     void decr_val_freq(){ Frequency--; };
-    unsigned int Index() const { return index; };
+    size_t Index() const { return index; };
     const std::string& Name() const { return name; };
     friend std::ostream& operator<<( std::ostream& os, ValueClass const *vc );
   protected:
     const std::string& name;
-    unsigned int index;
+    size_t index;
     size_t Frequency;
     ValueClass( const ValueClass& );
     ValueClass& operator=( const ValueClass& );
@@ -168,7 +165,7 @@ namespace Timbl {
   
   class TargetValue: public ValueClass {
   public:
-    TargetValue( const std::string&, unsigned int );
+    TargetValue( const std::string&, size_t );
   };
   
   class SparseValueProbClass {
@@ -191,7 +188,7 @@ namespace Timbl {
     friend struct D_D;
   public:
     FeatureValue( const std::string& );
-    FeatureValue( const std::string&, unsigned int );
+    FeatureValue( const std::string&, size_t );
     ~FeatureValue();
     void ReconstructDistribution( const ValueDistribution& vd ) { 
       TargetDist.Merge( vd );
@@ -206,12 +203,12 @@ namespace Timbl {
     FeatureValue& operator=( const FeatureValue& );
   };
     
-  typedef std::map< unsigned int, ValueClass *> IVCmaptype;
+  typedef std::map< size_t, ValueClass *> IVCmaptype;
   typedef std::vector<ValueClass *> VCarrtype;
 
   class BaseFeatTargClass: public MsgClass {
   public:
-    BaseFeatTargClass( StringHash * );
+    BaseFeatTargClass( Hash::StringHash * );
     virtual ~BaseFeatTargClass();
     size_t EffectiveValues() const;
     size_t TotalValues() const;
@@ -219,7 +216,7 @@ namespace Timbl {
     IVCmaptype ValuesMap;
     virtual ValueClass *Lookup( const std::string& ) const = 0;
   protected:
-    StringHash *TokenTree;
+    Hash::StringHash *TokenTree;
     bool is_copy;
     BaseFeatTargClass( const BaseFeatTargClass& );
   private:
@@ -229,11 +226,11 @@ namespace Timbl {
   
   class Target: public BaseFeatTargClass {
   public:
-    Target( StringHash *T ): BaseFeatTargClass(T) {};
+  Target( Hash::StringHash *T ): BaseFeatTargClass(T) {};
     TargetValue *add_value( const std::string&, int freq = 1 );
-    TargetValue *add_value( unsigned int, int freq = 1 );
+    TargetValue *add_value( size_t, int freq = 1 );
     TargetValue *Lookup( const std::string& ) const;
-    TargetValue *ReverseLookup( unsigned int ) const;
+    TargetValue *ReverseLookup( size_t ) const;
     bool decrement_value( TargetValue * );
     bool increment_value( TargetValue * );
     TargetValue *MajorityClass() const;
@@ -244,7 +241,7 @@ namespace Timbl {
   class Feature: public BaseFeatTargClass {
     friend class MBLClass;
   public:
-    Feature( StringHash *T );
+    Feature( Hash::StringHash *T );
     ~Feature();
     bool Ignore() const { return ignore; };
     void Ignore( const bool val ){ ignore = val; };
@@ -269,8 +266,8 @@ namespace Timbl {
     double Max() const { return n_max; };
     void Max( const double val ){ n_max = val; };
     double fvDistance( FeatureValue *, FeatureValue *, size_t=1 ) const;
-    FeatureValue *add_value( const std::string&, TargetValue * );
-    FeatureValue *add_value( unsigned int, TargetValue * );
+    FeatureValue *add_value( const std::string&, TargetValue *, int=1 );
+    FeatureValue *add_value( size_t, TargetValue *, int=1 );
     FeatureValue *Lookup( const std::string& ) const ;
     bool decrement_value( FeatureValue *, TargetValue * );
     bool increment_value( FeatureValue *, TargetValue * );
@@ -280,7 +277,7 @@ namespace Timbl {
     void InitSparseArrays();
     bool ArrayRead(){ return vcpb_read; };
     bool matrixPresent( bool& ) const;
-    unsigned int matrix_byte_size() const;
+    size_t matrix_byte_size() const;
     bool store_matrix( int = 1 );
     void clear_matrix();
     bool fill_matrix( std::istream& );
@@ -338,12 +335,15 @@ namespace Timbl {
     void clear();
     double ExemplarWeight() const { return sample_weight; }; 
     void ExemplarWeight( const double sw ){ sample_weight = sw; }; 
+    int Occurrences() const { return occ; };
+    void Occurrences( const int o ) { occ = o; };
     size_t size() const { return FV.size(); };
     std::vector<FeatureValue *> FV;
     void permute( const std::vector<size_t> );
     TargetValue *TV;
   private:
     double sample_weight; // relative weight
+    int occ;
   };
   
 }
