@@ -1,8 +1,8 @@
 /*
-  $Id: Metrics.h 9072 2011-03-23 09:20:03Z sloot $
+  $Id: Metrics.h 15264 2012-10-10 10:13:54Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/Metrics.h $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -27,8 +27,8 @@
       timbl@uvt.nl
 */
 
-#ifndef METRICS_H
-#define METRICS_H
+#ifndef TIMBL_METRICS_H
+#define TIMBL_METRICS_H
 
 #include <limits> 
 
@@ -150,4 +150,4 @@ namespace Timbl{
 
 }  
 
-#endif // METRICS_H
+#endif // TIMBL_METRICS_H
