@@ -1,8 +1,8 @@
 /*
-  $Id: MsgClass.h 9072 2011-03-23 09:20:03Z sloot $
+  $Id: MsgClass.h 15264 2012-10-10 10:13:54Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/MsgClass.h $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -26,8 +26,8 @@
   or send mail to:
       timbl@uvt.nl
 */
-#ifndef MSGCLASS_H
-#define MSGCLASS_H
+#ifndef TIMBL_MSGCLASS_H
+#define TIMBL_MSGCLASS_H
 
 namespace Timbl {
   class MsgClass{
