@@ -1,8 +1,8 @@
 /*
-  $Id: Testers.h 9072 2011-03-23 09:20:03Z sloot $
+  $Id: Testers.h 15264 2012-10-10 10:13:54Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/Testers.h $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -27,8 +27,8 @@
       timbl@uvt.nl
 */
 
-#ifndef TESTERS_H
-#define TESTERS_H
+#ifndef TIMBL_TESTERS_H
+#define TIMBL_TESTERS_H
 
 namespace Timbl{
   class metricTestFunction {
@@ -131,4 +131,4 @@ namespace Timbl{
 
 }  
 
-#endif // TESTERS_H
+#endif // TIMBL_TESTERS_H
