@@ -1,8 +1,8 @@
 /*
-  $Id: TimblExperiment.h 13052 2011-08-31 14:01:14Z sloot $
+  $Id: TimblExperiment.h 15264 2012-10-10 10:13:54Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/TimblExperiment.h $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -27,8 +27,8 @@
       timbl@uvt.nl
 */
 
-#ifndef TIMBLEXP_H
-#define TIMBLEXP_H
+#ifndef TIMBL_EXPERIMENT_H
+#define TIMBL_EXPERIMENT_H
 
 #include <fstream>
 #include <set>
@@ -422,4 +422,4 @@ namespace Timbl {
   
 }
 
-#endif // TIMBLEXP_H
+#endif // TIMBL_EXPERIMENT_H
