@@ -1,8 +1,8 @@
 /*
-  $Id: Types.h 13052 2011-08-31 14:01:14Z sloot $
+  $Id: Types.h 15264 2012-10-10 10:13:54Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/Types.h $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -27,8 +27,8 @@
       timbl@uvt.nl
 */
 
-#ifndef TYPES_H
-#define TYPES_H
+#ifndef TIMBL_TYPES_H
+#define TIMBL_TYPES_H
 
 #include <string>
 #include <set>
@@ -39,66 +39,11 @@
 #include <ostream>
 #include <sstream>
 
-#include "StringOps.h"
+#include "ticcutils/StringOps.h"
+#include "timbl/StringOps.h"
 
 namespace Timbl {
 
-  template< typename T >
-    std::ostream& operator<< ( std::ostream& os, const std::set<T>& s ){
-    os << "{";
-    typename std::set<T>::const_iterator it = s.begin();
-    while ( it != s.end() ){
-      os << *it;
-      ++it;
-      if ( it != s.end() )
-	os << ",";
-    }
-    os << "}";
-    return os;
-  }
-
-  template< typename T >
-    std::ostream& operator<< ( std::ostream& os, const std::vector<T>& s ){
-    os << "[";
-    typename std::vector<T>::const_iterator it = s.begin();
-    while ( it != s.end() ){
-      os << *it;
-      ++it;
-      if ( it != s.end() )
-	os << ",";
-    }
-    os << "]";
-    return os;
-  }
-
-  template< typename S, typename T >
-    std::ostream& operator<< ( std::ostream& os, const std::map<S,T>& s ){
-    os << "{";
-    typename std::map<S,T>::const_iterator it = s.begin();
-    while ( it != s.end() ){
-      os << "<" << it->first << "," << it->second << ">";
-      ++it;
-      if ( it != s.end() )
-	os << ",";
-    }
-    os << "}";
-    return os;
-  }
-
-  template< typename S, typename T, typename U >
-    std::ostream& operator<< ( std::ostream& os, const std::map<S,T,U>& s ){
-    os << "{";
-    typename std::map<S,T,U>::const_iterator it = s.begin();
-    while ( it != s.end() ){
-      os << "<" << it->first << "," << it->second << ">";
-      ++it;
-      if ( it != s.end() )
-	os << ",";
-    }
-    os << "}";
-    return os;
-  }
-
   template< typename T >
     T stringTo( const std::string& str ) {
     T result;
@@ -146,7 +91,7 @@ namespace Timbl {
   }
   
   enum InputFormatType { UnknownInputFormat,
-			 Compact, C4_5, Columns, ARFF, SparseBin,
+			 Compact, C4_5, Columns, Tabbed, ARFF, SparseBin,
 			 Sparse,
 			 MaxInputFormat };
   
@@ -500,7 +445,7 @@ namespace Timbl {
   template <>
     inline VerbosityFlags stringTo<VerbosityFlags>( const std::string& str ) { 
     std::vector<std::string> tmp;
-    size_t cnt = split_at( str, tmp, "+" ); 
+    size_t cnt = TiCC::split_at( str, tmp, "+" ); 
     VerbosityFlags V = NO_VERB;
     for ( size_t i=0; i < cnt; ++i ){
       VerbosityFlags Flag;
