@@ -1,8 +1,8 @@
 /*
-  $Id: BestArray.cxx 13480 2011-10-27 15:21:26Z sloot $
+  $Id: BestArray.cxx 15266 2012-10-10 11:00:27Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/BestArray.cxx $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -33,9 +33,7 @@
 
 #include "timbl/Common.h"
 #include "timbl/MsgClass.h"
-#include "timbl/StringOps.h"
 #include "timbl/Types.h"
-#include "timbl/Tree.h"
 #include "timbl/Instance.h"
 #include "timbl/neighborSet.h"
 #include "timbl/XMLtools.h"
