@@ -1,8 +1,8 @@
 /*
-  $Id: Choppers.cxx 9072 2011-03-23 09:20:03Z sloot $
+  $Id: Choppers.cxx 15241 2012-10-02 11:26:24Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/Choppers.cxx $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -32,7 +32,7 @@
 #include <vector>
 #include <string>
 #include <cassert>
-#include "timbl/StringOps.h"
+#include "ticcutils/StringOps.h"
 #include "timbl/Types.h"
 #include "timbl/Choppers.h"
 
@@ -40,43 +40,62 @@ using namespace std;
 
 namespace Timbl{
 
-  Chopper *Chopper::create( InputFormatType IF, bool doEx, int fLen ){
+  Chopper *Chopper::create( InputFormatType IF, bool doEx, 
+			    int fLen, bool doOcc ){
     Chopper *result = 0;
     switch ( IF ){
     case C4_5:
-      if ( doEx )
+      if ( doOcc )
+	result = new C45_OccChopper();
+      else if ( doEx )
 	result = new C45_ExChopper();
       else
 	result = new C45_Chopper();
       break;
     case ARFF:
-      if ( doEx )
+      if ( doOcc )
+	result = new ARFF_OccChopper();
+      else if ( doEx )
 	result = new ARFF_ExChopper();
       else
 	result = new ARFF_Chopper();
       break;
     case SparseBin:
-      if ( doEx )
+      if ( doOcc )
+	result = new Bin_OccChopper();
+      else if ( doEx )
 	result = new Bin_ExChopper();
       else
 	result = new Bin_Chopper();
-      //      do_sparse = true;
       break;
     case Sparse:
-      if ( doEx )
+      if ( doOcc )
+	result = new Sparse_OccChopper();
+      else if ( doEx )
 	result = new Sparse_ExChopper();
       else
 	result = new Sparse_Chopper();
-      //      do_sparse = true;
       break;
     case Columns:
-      if ( doEx )
+      if ( doOcc )
+	result = new Columns_OccChopper();
+      else if ( doEx )
 	result = new Columns_ExChopper();
       else
 	result = new Columns_Chopper();
       break;
+    case Tabbed:
+      if ( doOcc )
+	result = new Tabbed_OccChopper();
+      else if ( doEx )
+	result = new Tabbed_ExChopper();
+      else
+	result = new Tabbed_Chopper();
+      break;      
     case Compact:
-      if ( doEx )
+      if ( doOcc )
+	result = new Compact_OccChopper( fLen );
+      else if ( doEx )
 	result = new Compact_ExChopper( fLen );
       else
 	result = new Compact_Chopper( fLen );
@@ -129,14 +148,18 @@ namespace Timbl{
     return string( Buffer, 0, e_pos+1 );
   }
 
+  static string stripOcc( const string& Buffer,
+			  string& wght ) {
+    return stripExemplarWeight( Buffer, wght );
+  }
 
   size_t Chopper::countFeatures( const string& inBuffer, 
 				 InputFormatType IF,  
 				 int F_length,
-				 bool chopEx ) {
+				 bool chopTail ) {
     size_t result = 0;
     string buffer;
-    if ( chopEx ){
+    if ( chopTail ){
       string dummy;
       buffer = stripExemplarWeight( inBuffer, dummy );
     }
@@ -170,6 +193,16 @@ namespace Timbl{
 	}
       };
       break;
+    case Tabbed:
+      for ( size_t j = 0; j < len; ++j ) {
+	if ( buffer[j] == '\t' ){
+	  result++;
+	  while ( buffer[++j]  == '\t' ){};
+	  if ( buffer[j] == '\0' )
+	    result--; // we had some trailing spaces
+	}
+      };
+      break;      
     default:
       throw logic_error( "CountFeatures: Illegal value in switch:" +
 			 toString(IF) );
@@ -179,10 +212,10 @@ namespace Timbl{
   
  
   InputFormatType Chopper::getInputFormat( const string& inBuffer,
-					   bool stripEx ) {
+					   bool stripTail ) {
     InputFormatType IF = UnknownInputFormat;
     string buffer;
-    if ( stripEx ){
+    if ( stripTail ){
       string dummy;
       buffer = stripExemplarWeight( inBuffer, dummy );
     }
@@ -250,16 +283,54 @@ namespace Timbl{
     strippedInput.erase( ++it , strippedInput.end() );
   }
 
+  void OccChopper::init( const string& s, size_t len, bool stripDot ) {
+    occ = 1;
+    strippedInput = s;
+    vSize = len+1;
+    choppedInput.resize(vSize);
+    string::iterator it = strippedInput.end();
+    --it;
+    // first trim trailing spaces 
+    while ( it != strippedInput.begin() && 
+	    isspace(*it) ) --it;
+    strippedInput.erase( ++it , strippedInput.end() );
+    string occS;
+    strippedInput = stripOcc( strippedInput, occS );
+    if ( occS.empty() ){
+      throw logic_error( "Missing occurence" );
+    }
+    else {
+      int tmp;
+      if ( !stringTo<int>( occS, tmp ) ){
+	throw runtime_error( "Wrong (non-integer) occurence value: '" + occS + "'" );
+      }
+      else {
+	occ = tmp;
+      }
+    }
+    it = strippedInput.end();
+    --it;
+    if ( stripDot ){
+      // first trim trailing dot
+      if ( it != strippedInput.begin() && *it == '.' )
+	--it;
+    }
+    // strip remaining trailing spaces
+    while ( it != strippedInput.begin() && 
+	    isspace(*it) ) --it;
+    strippedInput.erase( ++it , strippedInput.end() );
+  }
+
   bool C45_Chopper::chop( const string& InBuf, size_t len ){
     // Function that takes a line, and chops it up into substrings,
     // which represent the feature-values and the target-value.
     init( InBuf, len, true );
     vector<string> splits;
-    size_t res = split_at( strippedInput, splits, "," );
+    size_t res = TiCC::split_at( strippedInput, splits, "," );
     if ( res != vSize )
       return false;
     for ( size_t i=0; i < res ; ++i ){
-      choppedInput[i] = StrToCode( compress(splits[i]) );
+      choppedInput[i] = StrToCode( splits[i] );
     }
     return true;
   }
@@ -374,6 +445,37 @@ namespace Timbl{
     return res;
   }
   
+
+  
+  bool Tabbed_Chopper::chop( const string& InBuf, size_t len ){
+    // Lines look like this:
+    // one  two three bla
+    init( InBuf, len, false );
+    unsigned int i = 0;
+    string::size_type s_pos = 0;
+    string::size_type e_pos = strippedInput.find_first_of( "\t" );
+    while ( e_pos != s_pos && e_pos != string::npos && i < vSize ){
+      // stop if a zero length string is found or if too many entries show up
+      choppedInput[i++] = string( strippedInput, s_pos, e_pos - s_pos );
+      s_pos = strippedInput.find_first_not_of( "\t", e_pos );
+      e_pos = strippedInput.find_first_of( "\t", s_pos );
+    }
+    if ( e_pos != string::npos )
+      return false;
+    if ( s_pos != string::npos && i < vSize ){
+      choppedInput[i++] = StrToCode( string( strippedInput, s_pos ) );
+    }
+    return ( i == vSize ); // Enough?
+  }
+  
+  string Tabbed_Chopper::getString() const { 
+    string res;
+    for ( size_t i = 0; i < vSize; ++i ) {
+      res += CodeToStr( choppedInput[i] ) + "\t";
+    }
+    return res;
+  }
+  
   bool Sparse_Chopper::chop( const string& InBuf, size_t len ){
     // Lines look like this:
     // (12,value1) (25,value2) (333,value3) bla.
@@ -384,7 +486,7 @@ namespace Timbl{
     choppedInput[vSize-1] = "";
     string::size_type s_pos = strippedInput.find( "(" );
     if ( s_pos == string::npos )
-      choppedInput[vSize-1] = compress(strippedInput);
+      choppedInput[vSize-1] = TiCC::trim(strippedInput);
     else {
       string::size_type m_pos, e_pos = strippedInput.find( ")" );
       while ( s_pos < e_pos &&
@@ -396,14 +498,14 @@ namespace Timbl{
 	  return false;
 	else {
 	  choppedInput[k-1] = string( strippedInput, m_pos + 1, e_pos - m_pos -1 );
-	  choppedInput[k-1] = StrToCode( compress(choppedInput[k-1]) );
+	  choppedInput[k-1] = StrToCode( choppedInput[k-1] );
 	}
 	s_pos = strippedInput.find( '(', e_pos );
 	if ( s_pos == string::npos ){
 	  e_pos = strippedInput.find_first_not_of( ") \t", e_pos );
 	  if ( e_pos != string::npos ){
 	    choppedInput[vSize-1] = string( strippedInput, e_pos );
-	    choppedInput[vSize-1] = compress( choppedInput[vSize-1] );
+	    choppedInput[vSize-1] = TiCC::trim( choppedInput[vSize-1] );
 	  }
 	}
 	else
