@@ -1,8 +1,8 @@
 /*
-  $Id: GetOptClass.cxx 13135 2011-09-12 08:41:06Z sloot $
+  $Id: GetOptClass.cxx 15266 2012-10-10 11:00:27Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/GetOptClass.cxx $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -35,10 +35,8 @@
 #include <ctime>
 #include <cctype>
 #include "timbl/Common.h"
-#include "timbl/StringOps.h"
 #include "timbl/Types.h"
 #include "timbl/Options.h"
-#include "timbl/Tree.h"
 #include "timbl/Instance.h"
 #include "timbl/Metrics.h"
 #include "timbl/CommandLine.h"
@@ -96,6 +94,7 @@ namespace Timbl {
     outPath = "";
     logFile = "";
     pidFile = "";
+    occIn = 0;
   }
   
   GetOptClass::GetOptClass( CL_Options& Opts ):
@@ -171,7 +170,8 @@ namespace Timbl {
     parent_socket_os( in.parent_socket_os ),
     outPath( in.outPath ),
     logFile( in.logFile ),
-    pidFile( in.pidFile )
+    pidFile( in.pidFile ),
+    occIn( in.occIn )
   {
   }
   
@@ -344,7 +344,15 @@ namespace Timbl {
 	Exp->SetOption(  "HASHED_TREE: true" );
       else
 	Exp->SetOption(  "HASHED_TREE: false" );
-      if ( do_sample_weights ){
+      if ( occIn > 0 &&
+	   do_sample_weights ){
+	Error( "--occurrences and -s cannot be combined!" );
+	return false;
+      }
+      if ( occIn > 0 ){
+	Exp->SetOption( "HANDLE_OCCURRENCES: " + toString(occIn) );
+      }
+      else if ( do_sample_weights ){
 	Exp->SetOption(  "EXEMPLAR_WEIGHTS: true" );
 	if ( do_ignore_samples )
 	  Exp->SetOption( "IGNORE_EXEMPLAR_WEIGHTS: true" );
@@ -494,8 +502,8 @@ namespace Timbl {
   
   inline bool GetOptClass::parse_metrics( const string& Mline,
 					  MetricType& Def ){
-    string line = compress( Mline );
-    uppercase( line );
+    string line = TiCC::trim( Mline );
+    TiCC::to_upper( line );
     string::iterator p = line.begin();
     if ( p != line.end() ){
       switch ( *p++ ){
@@ -656,8 +664,7 @@ namespace Timbl {
       return true;
     }
     else {
-      string s = in;
-      uppercase(s);
+      string s = TiCC::uppercase( in );
       if ( s == "TRUE" || s == "YES" || s == "FALSE" || s == "NO" ){
 	val = ( s == "TRUE" || s == "YES" );
 	return true;
@@ -680,7 +687,7 @@ namespace Timbl {
     const char *ok_opt;
     switch ( mode ){
     case 0: 
-      ok_opt = "a:b:B:c:C:d:De:F:G:Hk:l:L:m:M:n:N:O:p:q:QR:sS:t:T:v:w:Wx"; 
+      ok_opt = "a:b:B:c:C:d:De:F:G:Hk:l:L:m:M:n:N:o:O:p:q:QR:sS:t:T:v:w:Wx"; 
       break;
     case 1:
       // limited usage, for @t
@@ -1012,6 +1019,35 @@ namespace Timbl {
       case 'O':
 	outPath = myoptarg;
 	break;
+
+      case 'o':
+	if ( longOpt ){
+	  if ( long_option == "occurrences" ){
+	    if ( myoptarg.empty() ){
+	      Error( "missing value for '--occurrences'" );
+	      return false;
+	    }
+	    if ( myoptarg == "train" )
+	      occIn = 1;
+	    else if ( myoptarg == "test" )
+	      occIn = 2;
+	    else if ( myoptarg == "both" )
+	      occIn = 3;
+	    else {
+	      Error( "invalid --ocurrences value." );
+	      return false;
+	    }
+	  }
+	  else {
+	    Error( "invalid option: Did you mean '--ocurrences' ?" );
+	    return false;
+	  }
+	}
+	else if ( myoptarg.find("ccurences") != string::npos ){
+	  Error( "invalid option: Did you mean '--occurrences' ?" );
+	  return false;
+	}
+	break;
 	
       case 'p':
 	if ( longOpt ){
