@@ -1,8 +1,8 @@
 /*
-  $Id: IBtree.cxx 13733 2011-12-20 14:23:11Z sloot $
+  $Id: IBtree.cxx 15266 2012-10-10 11:00:27Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/IBtree.cxx $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -36,10 +36,10 @@
 #include <ctime>
 #include <cstdio>
 
+#include "ticcutils/StringOps.h"
+#include "ticcutils/TreeHash.h"
 #include "timbl/Common.h"
-#include "timbl/StringOps.h"
 #include "timbl/MsgClass.h"
-#include "timbl/Tree.h"
 #include "timbl/Types.h"
 #include "timbl/Instance.h"
 #include "timbl/XMLtools.h"
@@ -274,19 +274,19 @@ namespace Timbl {
   
   xmlNode *to_node( const FeatureValue *fv ){
     xmlNode *result = XmlNewNode( "feature" );
-    XmlAddContent( result, encode(fv->Name()) );
+    XmlAddContent( result, fv->Name() );
     return result;
   }
 
   xmlNode *to_node( const TargetValue *tv ){
     xmlNode *result = XmlNewNode( "target" );
-    XmlAddContent( result, encode(tv->Name()) );
+    XmlAddContent( result, tv->Name() );
     return result;
   }
 
   xmlNode *to_node( const ValueDistribution *d ){
     xmlNode *result = XmlNewNode( "distribution" );
-    XmlAddContent( result, d->ToEncodedString() );
+    XmlAddContent( result, d->DistToString() );
     return result;
   }
   
@@ -392,7 +392,9 @@ namespace Timbl {
     }
   }
   
-  void save_hash( ostream &os, StringHash *cats, StringHash *feats ){
+  void save_hash( ostream &os,
+		  Hash::StringHash *cats, 
+		  Hash::StringHash *feats ){
     int Size = cats->NumOfEntries();
     os << "Classes" << endl;
     for ( int i=1; i <= Size; ++i )
@@ -405,8 +407,8 @@ namespace Timbl {
   }
   
   void InstanceBase_base::Save( ostream &os, 
-				StringHash *cats, 
-				StringHash *feats,
+				Hash::StringHash *cats, 
+				Hash::StringHash *feats,
 				bool persist ) {
     // save an IBtree for later use.
     bool temp_persist =  PersistentDistributions;
@@ -487,7 +489,7 @@ namespace Timbl {
     string buf;
     char delim;
     is >> ws >> buf;
-    result->FValue = Feats[level]->add_value( buf, NULL );
+    result->FValue = Feats[level]->add_value( buf, NULL, 1 );
     is >> delim;
     if ( !is || delim != '(' ){
       Error( "missing `(` in Instance Base file" );
@@ -552,7 +554,7 @@ namespace Timbl {
     char delim;
     int index;
     is >> index;
-    result->FValue = Feats[level]->add_value( index, NULL );
+    result->FValue = Feats[level]->add_value( index, NULL, 1 );
     is >> delim;
     if ( !is || delim != '(' ){
       Error( "missing `(` in Instance Base file" );
@@ -695,8 +697,8 @@ namespace Timbl {
   }
   
   bool InstanceBase_base::read_hash( istream &is, 
-				     StringHash *cats,
-				     StringHash *feats ) const {
+				     Hash::StringHash *cats,
+				     Hash::StringHash *feats ) const {
     string line;
     is >> ws;
     is >> line;
@@ -707,7 +709,7 @@ namespace Timbl {
     is >> ws;
     vector<string> vals;
     while ( getline( is, line ) ){
-      size_t i = split( line, vals );
+      size_t i = TiCC::split( line, vals );
       if ( i == 2 )
 	// just ignore index!
 	cats->Hash( vals[1] );
@@ -720,7 +722,7 @@ namespace Timbl {
       return false;
     }
     while ( getline( is, line ) ){
-      size_t i = split( line, vals );
+      size_t i = TiCC::split( line, vals );
       if ( i == 2 )
 	// just ignore index!
 	feats->Hash( vals[1] );
@@ -732,7 +734,8 @@ namespace Timbl {
   
   bool InstanceBase_base::ReadIB( istream &is, 
 				  vector<Feature *>& Feats, Target *Targs,
-				  StringHash *cats, StringHash *feats,
+				  Hash::StringHash *cats, 
+				  Hash::StringHash *feats,
 				  int expected_version ){
     if ( read_IB( is, Feats, Targs, cats, feats, expected_version ) ){
       InstBase->redo_distributions();
@@ -748,7 +751,7 @@ namespace Timbl {
   
   bool IG_InstanceBase::ReadIB( istream &is, 
 				vector<Feature *>& Feats, Target *Targs,
-				StringHash *cats, StringHash *feats,
+				Hash::StringHash *cats, Hash::StringHash *feats,
 				int expected_version ){
     if ( read_IB( is, Feats, Targs, cats, feats, expected_version ) ){
       if ( PersistentDistributions ){
@@ -765,7 +768,8 @@ namespace Timbl {
   
   bool InstanceBase_base::read_IB( istream &is, 
 				   vector<Feature *>& Feats, Target *Targs,
-				   StringHash *cats, StringHash *feats,
+				   Hash::StringHash *cats, 
+				   Hash::StringHash *feats,
 				   int expected_version ){
     char delim;
     int dum;
@@ -1245,6 +1249,7 @@ namespace Timbl {
   }
   
   bool InstanceBase_base::AddInstance( const Instance& Inst ){
+    bool sw_conflict = false;
     // add one instance to the IB
     IBtree *hlp, **pnt = &InstBase;
 #ifdef IBSTATS
@@ -1281,19 +1286,19 @@ namespace Timbl {
 	(*pnt)->TDistribution = new ValueDistribution;
       NumOfTails++;
     }
-    bool sw_conflict = false;
+    int occ = Inst.Occurrences();
     if ( abs( Inst.ExemplarWeight() ) > Epsilon ){
-      sw_conflict = (*pnt)->TDistribution->IncFreq( Inst.TV, 
+      sw_conflict = (*pnt)->TDistribution->IncFreq( Inst.TV, occ,
 						    Inst.ExemplarWeight() );
     }
-    else
-      (*pnt)->TDistribution->IncFreq(Inst.TV);
-    TopDistribution->IncFreq(Inst.TV);
+    else {
+      (*pnt)->TDistribution->IncFreq(Inst.TV, occ );
+    }
+    TopDistribution->IncFreq(Inst.TV, occ );
     DefaultsValid = false;
     return !sw_conflict;
   }
 
-
   bool InstanceBase_base::MergeSub( InstanceBase_base *ib ){
     if ( ib->InstBase ){
       // we place the InstanceBase of ib in front of the current InstanceBase
@@ -1421,22 +1426,24 @@ namespace Timbl {
   }
 
   void InstanceBase_base::RemoveInstance( const Instance& Inst ){
-    // remove an instance from the IB
-    int pos = 0;
-    IBtree *pnt = InstBase;
-    while ( pnt ){
-      if ( pnt->link == NULL ){
-	pnt->TDistribution->DecFreq(Inst.TV);
-	TopDistribution->DecFreq(Inst.TV);
-	break;
-      }
-      else {
-	if ( pnt->FValue == Inst.FV[pos] ){
-	  pnt = pnt->link;
-	  pos++;
+    for ( int occ=0; occ < Inst.Occurrences(); ++occ ){
+      // remove an instance from the IB
+      int pos = 0;
+      IBtree *pnt = InstBase;
+      while ( pnt ){
+	if ( pnt->link == NULL ){
+	  pnt->TDistribution->DecFreq(Inst.TV);
+	  TopDistribution->DecFreq(Inst.TV);
+	  break;
+	}
+	else {
+	  if ( pnt->FValue == Inst.FV[pos] ){
+	    pnt = pnt->link;
+	    pos++;
+	  }
+	  else
+	    pnt = pnt->next;
 	}
-	else
-	  pnt = pnt->next;
       }
     }
     DefaultsValid = false;
