@@ -1,8 +1,8 @@
 /*
-  $Id: IGExperiment.cxx 10513 2011-06-10 11:08:47Z sloot $
+  $Id: IGExperiment.cxx 15266 2012-10-10 11:00:27Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/IGExperiment.cxx $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -38,10 +38,8 @@
 
 #include "timbl/MsgClass.h"
 #include "timbl/Common.h"
-#include "timbl/StringOps.h"
 #include "timbl/Types.h"
 #include "timbl/Options.h"
-#include "timbl/Tree.h"
 #include "timbl/Instance.h"
 #include "timbl/IBtree.h"
 #include "timbl/TimblExperiment.h"
