@@ -1,8 +1,8 @@
 /*
-  $Id: Instance.cxx 13727 2011-12-20 11:51:57Z sloot $
+  $Id: Instance.cxx 15266 2012-10-10 11:00:27Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/Instance.cxx $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -37,16 +37,13 @@
 #include <typeinfo>
 #include <cmath>
 #include <cstdio>
-#include <cstdlib>
-#include <cctype>
-#include <cstring>
-#include <cfloat>
 #include <cassert>
 
+#include "ticcutils/StringOps.h"
+#include "ticcutils/TreeHash.h"
+
 #include "timbl/Common.h"
-#include "timbl/StringOps.h"
 #include "timbl/MsgClass.h"
-#include "timbl/Tree.h"
 #include "timbl/Types.h"
 #include "timbl/Instance.h"
 #include "timbl/Metrics.h"
@@ -99,44 +96,6 @@ namespace Timbl {
     return 0.0;
   }
   
-  void ValueDistribution::DistToEncodedString( string& DistStr ) const {
-    ostringstream oss;
-    VDlist::const_iterator it = distribution.begin();
-    oss << "{ ";
-    while ( it != distribution.end() ){
-      Vfield *f = it->second;
-      if ( f->Freq() <= 0 ){
-	++it;
-	continue;
-      }
-      oss << encode(f->Value()->Name())<< " " << f->Freq();
-      ++it;
-      if ( it != distribution.end() )
-	oss << ", ";
-    }
-    oss << " }";
-    DistStr = oss.str();
-  }
-
-  void WValueDistribution::DistToEncodedString( string& DistStr ) const {
-    ostringstream oss;
-    VDlist::const_iterator it = distribution.begin();
-    oss << "{ ";
-    while ( it != distribution.end() ){
-      Vfield *f = it->second;
-      if ( abs(f->weight) < Epsilon ){
-	++it;
-	continue;
-      }
-      oss << encode(f->value->Name()) << " " << f->weight;
-      ++it;
-      if ( it != distribution.end() )
-	oss << ", ";
-    }
-    oss << " }";
-    DistStr = oss.str();
-  }
-
   void ValueDistribution::DistToString( string& DistStr, double minf ) const {
     ostringstream oss;
     VDlist::const_iterator it = distribution.begin();
@@ -145,18 +104,12 @@ namespace Timbl {
     oss << "{ ";
     while ( it != distribution.end() ){
       Vfield *f = it->second;
-      if ( f->frequency < minf ){
-	++it;
-	continue;
+      if ( f->frequency >= minf ){
+	if ( !first )
+	  oss << ", ";
+	oss << f->value << " " << double(f->frequency);
+	first = false;
       }
-      if ( abs(f->frequency) < Epsilon ){
-	++it;
-	continue;
-      }
-      if ( !first )
-	oss << ", ";
-      oss << f->value << " " << double(f->frequency);
-      first = false;
       ++it;
     }
     oss << " }";
@@ -171,7 +124,7 @@ namespace Timbl {
     oss << "{ ";
     while ( it != distribution.end() ){
       Vfield *f = it->second;
-      if (  abs(f->weight) < minw ){
+      if ( abs(f->weight) < minw ){
 	++it;
 	continue;
       }
@@ -255,12 +208,6 @@ namespace Timbl {
     return result;
   }
 
-  const string ValueDistribution::ToEncodedString() const {
-    string result;
-    DistToEncodedString( result );
-    return result;
-  }  
-  
   double ValueDistribution::Entropy() const {
     double Prob = 0.0;
     double entropy = 0.0;
@@ -384,14 +331,16 @@ namespace Timbl {
     ostringstream oss;
     VDlist::const_iterator it = distribution.begin();
     oss << "{ ";
+    bool first = true;
     while ( oss.good() && it != distribution.end() ){
       Vfield *f = it->second;
       if ( f->frequency > 0 ){
+	if ( !first )
+	  oss << ", ";
 	oss << f->value->Index() << " " << f->frequency;
+	first = false;
       }
       ++it;
-      if ( it != distribution.end() )
-	oss << ", ";
     }
     oss << " }";
     return oss.str();
@@ -400,16 +349,18 @@ namespace Timbl {
   const string WValueDistribution::SaveHashed() const{
     ostringstream oss;
     VDlist::const_iterator it = distribution.begin();
+    bool first = true;
     oss << "{ ";
     while ( oss.good() && it != distribution.end() ){
       Vfield *f = it->second;
       if ( f->frequency > 0 ){
+	if ( !first )
+	  oss << ", ";
 	oss << f->Value()->Index() << " " 
 	    << f->frequency << " " << f->weight;
+	first = false;
       }
       ++it;
-      if ( it != distribution.end() )
-	oss << ", ";
     }
     oss << " }";
     return oss.str();
@@ -423,14 +374,16 @@ namespace Timbl {
     ostringstream oss;
     VDlist::const_iterator it = distribution.begin();
     oss << "{ ";
+    bool first = true;
     while ( oss.good() && it != distribution.end() ){
       Vfield *f = it->second;
       if ( f->frequency > 0 ){
+	if ( !first )
+	  oss << ", ";
 	oss << f->value << " " << f->frequency;
+	first = false;
       }
       ++it;
-      if ( it != distribution.end() )
-	oss << ", ";
     }
     oss << " }";
     return oss.str();
@@ -440,15 +393,17 @@ namespace Timbl {
     ostringstream oss;
     VDlist::const_iterator it = distribution.begin();
     oss << "{ ";
+    bool first = true;
     while ( oss.good() && it != distribution.end() ){
       Vfield *f = it->second;
       if ( f->frequency > 0 ){
+	if ( !first )
+	  oss << ", ";
 	oss.setf(ios::showpoint);
 	oss << f->value << " " << f->frequency << " " << f->weight;
+	first = false;
       }
       ++it;
-      if ( it != distribution.end() )
-	oss << ", ";
     }
     oss << " }";
     return oss.str();
@@ -471,33 +426,37 @@ namespace Timbl {
     total_items += freq;
   }
   
-  bool ValueDistribution::IncFreq( const TargetValue *val, double ){
-    // search for val, if not there: add entry with frequency 1;
+  bool ValueDistribution::IncFreq( const TargetValue *val, 
+				   size_t occ, 
+				   double ){
+    // search for val, if not there: add entry with frequency 'occ';
     // otherwise increment the freqency
     size_t id = val->Index(); 
     VDlist::const_iterator it = distribution.find( id );
     if ( it != distribution.end() ){
-      it->second->IncFreq();
+      it->second->IncFreq( occ );
     }
     else
-      distribution[id] = new Vfield( val, 1, 1.0 );
-    total_items += 1;
+      distribution[id] = new Vfield( val, occ, 1.0 );
+    total_items += occ;
     return true;
   }
   
-  bool WValueDistribution::IncFreq( const TargetValue *val, double sw ){
-    // search for val, if not there: add entry with frequency 1;
+  bool WValueDistribution::IncFreq( const TargetValue *val, 
+				    size_t occ,
+				    double sw ){
+    // search for val, if not there: add entry with frequency 'occ';
     // otherwise increment the freqency
     // also set sample weight
     size_t id = val->Index(); 
     VDlist::const_iterator it = distribution.find( id );
     if ( it != distribution.end() ){
-      it->second->IncFreq();
+      it->second->IncFreq( occ );
     }  
     else {
-      distribution[id] = new Vfield( val, 1, sw );
+      distribution[id] = new Vfield( val, occ, sw );
     }
-    total_items += 1;
+    total_items += occ;
     return fabs( distribution[id]->Weight() - sw ) > Epsilon;
   }
   
@@ -560,7 +519,7 @@ namespace Timbl {
     VDlist::const_iterator It = distribution.begin();
     if ( It != distribution.end() ){
       Vfield *pnt = It->second;
-      int Max = pnt->Freq();
+      size_t Max = pnt->Freq();
       if ( do_rand ){
 	int nof_best=1, pick=1;
 	++It;
@@ -675,7 +634,7 @@ namespace Timbl {
     return best;
   }
 
-  Feature::Feature( StringHash *T ): 
+  Feature::Feature( Hash::StringHash *T ): 
     BaseFeatTargClass(T),
     metric_matrix( 0 ),
     metric( 0 ),
@@ -1131,7 +1090,7 @@ namespace Timbl {
     ValueDistribution *result = 0;
     TargetValue *target;
     string buf;
-    int freq;
+    size_t freq;
     double sw;
     char nextCh;
     is >> nextCh;   // skip {
@@ -1199,7 +1158,7 @@ namespace Timbl {
     // otherwise 1. Special case when reading the TopDistribution.
     //
     TargetValue *target;
-    int freq;
+    size_t freq;
     unsigned int index;
     double sw;
     char nextCh;
@@ -1268,7 +1227,7 @@ namespace Timbl {
   }
   
   FeatureValue::FeatureValue( const std::string& value,
-			      unsigned int hash_val ):
+			      size_t hash_val ):
     ValueClass( value, hash_val ), ValueClassProb( NULL ) {
   }
   
@@ -1283,11 +1242,11 @@ namespace Timbl {
   }
   
   TargetValue::TargetValue( const std::string& value,
-			    unsigned int value_hash ):
+			    size_t value_hash ):
     ValueClass( value, value_hash ){}
   
   size_t BaseFeatTargClass::EffectiveValues() const {
-    int result = 0;
+    size_t result = 0;
     VCarrtype::const_iterator it = ValuesArray.begin();
     while( it != ValuesArray.end() ){
       if ( (*it)->ValFreq() > 0 )
@@ -1319,28 +1278,31 @@ namespace Timbl {
   }
 
   FeatureValue *Feature::add_value( const string& valstr, 
-				    TargetValue *tv ){
+				    TargetValue *tv, 
+				    int freq ){
     unsigned int hash_val = TokenTree->Hash( valstr );
-    return add_value( hash_val, tv );
+    return add_value( hash_val, tv, freq );
   }
   
-  FeatureValue *Feature::add_value( unsigned int index, 
-				    TargetValue *tv ){
+  FeatureValue *Feature::add_value( size_t index, 
+				    TargetValue *tv,
+				    int freq ){
     IVCmaptype::const_iterator it = ValuesMap.find( index );
     if(  it == ValuesMap.end() ){
       const string& value = TokenTree->ReverseLookup( index );
       // we want to store the singleton value for this index
       // so we MUST reverse lookup the index
       FeatureValue *fv = new FeatureValue( value, index );
+      fv->ValFreq( freq );
       ValuesMap[index] = fv;
       ValuesArray.push_back( fv );
     }
     else {
-      it->second->incr_val_freq();
+      it->second->IncValFreq( freq );
     }
     FeatureValue *result = (FeatureValue *)ValuesMap[index];
     if ( tv )
-      result->TargetDist.IncFreq(tv);
+      result->TargetDist.IncFreq(tv, freq );
     return result;
   }
   
@@ -1350,7 +1312,7 @@ namespace Timbl {
     if ( FV ){
       FV->incr_val_freq();
       if ( tv )
-	FV->TargetDist.IncFreq(tv);
+	FV->TargetDist.IncFreq(tv,1);
       result = true;
     }
     return result;
@@ -1398,7 +1360,7 @@ namespace Timbl {
       return false;
   }
 
-  BaseFeatTargClass::BaseFeatTargClass( StringHash *T ):
+  BaseFeatTargClass::BaseFeatTargClass( Hash::StringHash *T ):
     TokenTree( T ),
     is_copy(false){
   }
@@ -1424,7 +1386,7 @@ namespace Timbl {
   
   TargetValue *Target::Lookup( const string& str ) const {
     TargetValue *result = 0;
-    unsigned int index = TokenTree->Lookup( str );
+    size_t index = TokenTree->Lookup( str );
     if ( index ) {
       IVCmaptype::const_iterator it = ValuesMap.find( index );
       result = (TargetValue *)it->second;
@@ -1432,7 +1394,7 @@ namespace Timbl {
     return result;
   }
 
-  TargetValue *Target::ReverseLookup( unsigned int index ) const {
+  TargetValue *Target::ReverseLookup( size_t index ) const {
     IVCmaptype::const_iterator it = ValuesMap.find( index );
     return dynamic_cast<TargetValue *>(it->second);
   }
@@ -1461,7 +1423,7 @@ namespace Timbl {
     return false;
   }
   
-  unsigned int Feature::matrix_byte_size() const {
+  size_t Feature::matrix_byte_size() const {
     if ( metric_matrix )
       return metric_matrix->NumBytes();
     else
@@ -1722,7 +1684,7 @@ namespace Timbl {
       if ( line.empty() ) break;
       vector<string> arr;
       double d;
-      if ( split_at( line, arr, " " ) != 2 ){
+      if ( TiCC::split_at( line, arr, " " ) != 2 ){
 	Error( "wrong line in inputfile" );
 	return false;
       }
@@ -1737,7 +1699,7 @@ namespace Timbl {
       else {
 	string stripped = arr[0].substr(1,arr[0].length()-2);
 	vector<string> parts;
-	if ( split_at( stripped, parts, ",\t" ) != 2 ){
+	if ( TiCC::split_at( stripped, parts, ",\t" ) != 2 ){
 	  Error( "wrong line in inputfile" );
 	  return false;
 	}
@@ -1797,13 +1759,13 @@ namespace Timbl {
     return add_value( hash_val, freq );
   }
   
-  TargetValue *Target::add_value( unsigned int index, int freq ){
+  TargetValue *Target::add_value( size_t index, int freq ){
     IVCmaptype::const_iterator it = ValuesMap.find( index );
     if(  it == ValuesMap.end() ){
       const string& name = TokenTree->ReverseLookup( index );
       // we want to store the singleton value for this index
       // so we MUST reverse lookup the index
-      TargetValue *tv =  new TargetValue( name, index );
+      TargetValue *tv = new TargetValue( name, index );
       tv->ValFreq( freq );
       ValuesMap[index] = tv;
       ValuesArray.push_back( tv );
@@ -1847,7 +1809,7 @@ namespace Timbl {
   }
   
   Instance::Instance():
-    TV(NULL), sample_weight(0.0) {
+    TV(NULL), sample_weight(0.0), occ(1) {
   }
   
   Instance::~Instance(){
@@ -1865,6 +1827,7 @@ namespace Timbl {
     }
     TV = 0;
     sample_weight = 0.0;
+    occ = 1;
   }
   
   void Instance::Init( size_t len ){
