@@ -1,8 +1,8 @@
 /*
-  $Id: MBLClass.cxx 13622 2011-12-01 10:06:07Z sloot $
+  $Id: MBLClass.cxx 15266 2012-10-10 11:00:27Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/MBLClass.cxx $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -45,12 +45,13 @@
 #include <cctype>
 #include <cassert>
 
+#include "ticcutils/StringOps.h"
+#include "ticcutils/TreeHash.h"
+
 #include "timbl/MsgClass.h"
 #include "timbl/Common.h"
-#include "timbl/StringOps.h"
 #include "timbl/Types.h"
 #include "timbl/Options.h"
-#include "timbl/Tree.h"
 #include "timbl/Instance.h"
 #include "timbl/IBtree.h"
 #include "timbl/BestArray.h"
@@ -146,6 +147,8 @@ namespace Timbl {
 					&num_of_neighbors, 1, 1, 100000 ) )
 	&& Options.Add( new IntegerOption( "PROGRESS", 
 					   &progress, 10000, 1, INT_MAX ) )
+	&& Options.Add( new IntegerOption( "HANDLE_OCCURRENCES", 
+					   &doOcc, 0, 0, 3 ) )
 	&& Options.Add( new IntegerOption( "CLIP_FACTOR", 
 					   &clip_factor, 10, 0, 1000000 ) );
     }
@@ -417,13 +420,13 @@ namespace Timbl {
     ostringstream tmp;
     Options.Show_Settings( tmp );
     vector<string> lines;
-    int num = split_at( tmp.str(), lines, "\n" );
+    int num = TiCC::split_at( tmp.str(), lines, "\n" );
     xmlNode *result = XmlNewNode("settings");
     for ( int i=0; i < num; ++i ){
       vector<string> parts;
-      if ( split_at( lines[i], parts, ":" ) ==2 ){
-	string tag = compress( parts[0] );
-	string val = compress( parts[1] );
+      if ( TiCC::split_at( lines[i], parts, ":" ) ==2 ){
+	string tag = TiCC::trim( parts[0] );
+	string val = TiCC::trim( parts[1] );
 	XmlNewChild( result, tag, val );
       }
     }
@@ -685,7 +688,7 @@ namespace Timbl {
     bool skip = false;
     bool anything = false;
     while ( getline( is, line ) ){
-      line = compress( line );
+      line = TiCC::trim( line );
       if ( line.empty() )
 	continue;
       if ( line.find( "Feature" ) != 0 ){
@@ -707,7 +710,7 @@ namespace Timbl {
 	  if ( pos == string::npos )
 	    line = "";
 	  else {
-	    line = compress( line.substr( pos ) );
+	    line = TiCC::trim( line.substr( pos ) );
 	  }
 	  if ( line.empty() ){
 	    if ( !Features[num-1]->isStorableMetric() ){
@@ -927,19 +930,25 @@ namespace Timbl {
     if ( num_of_features != target_pos ) {
       ChopInput->swapTarget( target_pos );
     }
+    int occ = ChopInput->getOcc();
+    if ( occ > 1 ){
+      CurrInst.Occurrences( occ );
+    }
     switch ( phase  ){
     case LearnWords:
       // Add the target.
-      CurrInst.TV = Targets->add_value( ChopInput->getField( num_of_features ));
+      CurrInst.TV = Targets->add_value( ChopInput->getField( num_of_features ),
+					occ );
       // Now add the Feature values.
       for ( size_t i = 0; i < num_of_features; ++i ){
 	// when learning, no need to bother about Permutation
 	if ( Features[i]->Ignore() ) // but this might happen, take care!
 	  CurrInst.FV[i] = NULL;
-	else
+	else {
 	  // Add it to the Instance.
 	  CurrInst.FV[i] = Features[i]->add_value( ChopInput->getField(i),
-						   CurrInst.TV ); 
+						   CurrInst.TV, occ ); 
+	}
       } // i
       break;
     case TrainWords:
@@ -956,13 +965,14 @@ namespace Timbl {
       // Lookup for Incremental TreeBuilding
       // Assumes that somehow Permutation and effective_feats are known
       // First the Target
-      CurrInst.TV = Targets->add_value( ChopInput->getField(num_of_features ) );
+      CurrInst.TV = Targets->add_value( ChopInput->getField(num_of_features ),
+					occ );
       // Then the Features
       for ( size_t l = 0; l < effective_feats; ++l ){
 	size_t j = permutation[l];
 	CurrInst.FV[l] = Features[j]->add_value( ChopInput->getField(j),
-						 CurrInst.TV ); 
-      } // k
+						 CurrInst.TV, occ ); 
+      } // for l
       break;
     case TestWords:
       // Lookup for Testing
@@ -1185,7 +1195,7 @@ namespace Timbl {
 	// 13      Ignore
 	//
 	vector<string> vals;
-	if ( split( Buffer, vals ) == 2 ){
+	if ( TiCC::split( Buffer, vals ) == 2 ){
 	  size_t i_f = stringTo<size_t>( vals[0] );
 	  if ( i_f > num_of_features ){
 	    Error( "in weightsfile, Feature index > Maximum, (" +
@@ -1248,7 +1258,7 @@ namespace Timbl {
 	else {
 	  if ( Buffer[0] == '#'){
 	    vector<string> vals;
-	    if ( split_at( Buffer, vals, " " ) == 2  ){
+	    if ( TiCC::split_at( Buffer, vals, " " ) == 2  ){
 	      WeightType tmp_w = Unknown_w;
 	      if ( !stringTo<WeightType>( vals[1], tmp_w ) )
 		continue;
@@ -1544,7 +1554,7 @@ namespace Timbl {
       delete ChopInput;
       ChopInput = 0;
     }
-    ChopInput = Chopper::create( IF, chopExamples(), F_length );
+    ChopInput = Chopper::create( IF, chopExamples(), F_length, chopOcc() );
     if ( ChopInput ){
       input_format = IF;
       return true;
@@ -1609,6 +1619,12 @@ namespace Timbl {
 	else
 	  result += inst.FV[InvPerm[j]]->Name() + " ";
 	break;
+      case Tabbed:
+	if ( Features[j]->Ignore() )
+	  result += "-*- ";
+	else
+	  result += inst.FV[InvPerm[j]]->Name() + "\t";
+	break;	
       default:
 	if ( Features[j]->Ignore() )
 	  result += string( F_length, '*' );
@@ -1710,32 +1726,6 @@ namespace Timbl {
     tester = getTester( globalMetricOption, Features, permutation, mvd_threshold );
   }
 
-  ostream& operator<< ( ostream& os, const vector<FeatureValue*>& fv ){
-    vector<FeatureValue*>::const_iterator it= fv.begin();
-    os << "vector<";
-    while( it != fv.end() ){
-      os << *it;
-      ++it;
-      if ( it != fv.end() )
-	os << ",";
-    }
-    os << ">";
-    return os;
-  }
-
-  ostream& operator<< ( ostream& os, const vector<double>& fv ){
-    vector<double>::const_iterator it= fv.begin();
-    os << "vector<";
-    while( it != fv.end() ){
-      os << *it;
-      ++it;
-      if ( it != fv.end() )
-	os << ",";
-    }
-    os << ">";
-    return os;
-  }
-  
   void MBLClass::test_instance( const Instance& Inst,
 				InstanceBase_base *IB,
 				size_t ib_offset ){
@@ -1872,7 +1862,8 @@ namespace Timbl {
       return num_of_features;
     else {
       try {
-	result = Chopper::countFeatures( inBuffer, IF, F_length, chopExamples() );
+	result = Chopper::countFeatures( inBuffer, IF, F_length, 
+					 chopExamples() || chopOcc() );
       }
       catch( const runtime_error& e ){
 	Error( e.what() );
@@ -1885,7 +1876,7 @@ namespace Timbl {
   }
 
   InputFormatType MBLClass::getInputFormat( const string& inBuffer ) const {
-    return Chopper::getInputFormat( inBuffer, chopExamples() );
+    return Chopper::getInputFormat( inBuffer, chopExamples() || chopOcc() );
   }
 
   size_t MBLClass::examineData( const string& FileName ){
@@ -2011,8 +2002,8 @@ namespace Timbl {
 		  toString<size_t>( num_of_features+1 ) );
     Features.resize(num_of_features,NULL);
     PermFeatures.resize(num_of_features,NULL);
-    FeatureStrings = new StringHash(); // all features share the same hash
-    TargetStrings = new StringHash(); // targets has it's own hash
+    FeatureStrings = new Hash::StringHash(); // all features share the same hash
+    TargetStrings = new Hash::StringHash(); // targets has it's own hash
     Targets = new Target( TargetStrings );
     for ( size_t i=0; i< num_of_features; ++i ){
       Features[i] = new Feature( FeatureStrings );
