@@ -1,8 +1,8 @@
 /*
-  $Id: Testers.cxx 13733 2011-12-20 14:23:11Z sloot $
+  $Id: Testers.cxx 15266 2012-10-10 11:00:27Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/Testers.cxx $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -36,8 +36,6 @@
 #include <climits>
 
 #include "timbl/Common.h"
-#include "timbl/StringOps.h"
-#include "timbl/Tree.h"
 #include "timbl/Types.h"
 #include "timbl/Instance.h"
 #include "timbl/Metrics.h"
