@@ -1,8 +1,8 @@
 /*
-  $Id: Timbl.cxx 13733 2011-12-20 14:23:11Z sloot $
+  $Id: Timbl.cxx 15229 2012-09-27 13:45:39Z mvgompel $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/Timbl.cxx $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -147,7 +147,7 @@ inline void usage_full(void){
   cerr << "-f f      : read from Datafile 'f'" << endl;
   cerr << "-f f      : OR: use filenames from 'f' for CV test" << endl;
   cerr << "-F format : Assume the specified inputformat" << endl;
-  cerr << "            (Compact, C4.5, ARFF, Columns, Binary, Sparse )" 
+  cerr << "            (Compact, C4.5, ARFF, Columns, Tabbed, Binary, Sparse )" 
        << endl;
   cerr << "-l n      : length of Features (Compact format only)" << endl;
   cerr << "-i f      : read the InstanceBase from file 'f' "
@@ -156,6 +156,9 @@ inline void usage_full(void){
   cerr << "--matrixin=<f> read ValueDifference Matrices from file 'f'" << endl;
   cerr << "-u f      : read value_class probabilities from file 'f'" 
        << endl;
+  cerr << "--occurrences=train|test|both assume occurrence info in the files."
+       << endl;
+  cerr << "             (train: in the train file, test: in the test file, both: in both)" << endl;
   cerr << "-P d      : read data using path 'd'" << endl;
   cerr << "-s        : use exemplar weights from the input file" << endl;
   cerr << "-s0       : silently ignore the exemplar weights from the input file" << endl;
@@ -472,7 +475,7 @@ bool get_file_names( TimblOpts& Opts ){
   }
   if ( Opts.Find( "IL", value ) ){
     vector<string> vec;
-    int num = split_at( value, vec, ":" );
+    int num = TiCC::split_at( value, vec, ":" );
     if ( num > 1 ){
       levelTreeOutFile = correct_path( vec[0], O_Path, true );
       levelTreeLevel = stringTo<int>( vec[1] );
@@ -514,7 +517,7 @@ bool get_file_names( TimblOpts& Opts ){
     if ( !string_to( value, W ) ){
       // No valid weighting, so assume it also has a filename
       vector<string> parts;
-      size_t num = split_at( value, parts, ":" );
+      size_t num = TiCC::split_at( value, parts, ":" );
       if ( num == 2 ){
 	if ( !string_to( parts[1], W ) ){
 	  cerr << "invalid weighting option: " << value << endl;
@@ -717,7 +720,7 @@ int main(int argc, char *argv[]){
     // Start.
     //
     cerr << "TiMBL " << TimblAPI::VersionInfo()
-	 << " (c) ILK 1998 - 2011.\n" 
+	 << " (c) ILK 1998 - 2012.\n" 
 	 << "Tilburg Memory Based Learner\n"
 	 << "Induction of Linguistic Knowledge Research Group, Tilburg University\n"
 	 << "CLiPS Computational Linguistics Group, University of Antwerp" << endl;
