@@ -1,8 +1,8 @@
 /*
-  $Id: TimblAPI.cxx 12969 2011-08-24 14:00:22Z sloot $
+  $Id: TimblAPI.cxx 15266 2012-10-10 11:00:27Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/TimblAPI.cxx $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -29,11 +29,9 @@
 #include <map>
 #include <string>
 #include "timbl/Common.h"
-#include "timbl/StringOps.h"
 #include "timbl/MsgClass.h"
 #include "timbl/Types.h"
 #include "timbl/Options.h"
-#include "timbl/Tree.h"
 #include "timbl/Instance.h"
 #include "timbl/neighborSet.h"
 #include "timbl/BestArray.h"
