@@ -1,8 +1,8 @@
 /*
-  $Id: TimblExperiment.cxx 13733 2011-12-20 14:23:11Z sloot $
+  $Id: TimblExperiment.cxx 15266 2012-10-10 11:00:27Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/TimblExperiment.cxx $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -48,12 +48,11 @@
 #include <sys/time.h>
 
 #include "config.h"
+
 #include "timbl/MsgClass.h"
 #include "timbl/Common.h"
-#include "timbl/StringOps.h"
 #include "timbl/Types.h"
 #include "timbl/Options.h"
-#include "timbl/Tree.h"
 #include "timbl/Instance.h"
 #include "timbl/Choppers.h"
 #include "timbl/Metrics.h"
@@ -71,9 +70,11 @@
 #include <omp.h>
 #endif
 
+using namespace std;
+
 namespace Timbl {
-  using namespace std;
-  using namespace Timbl;
+  #include "ticcutils/PrettyPrint.h"
+  using namespace TiCC;
 
   resultStore::~resultStore( ) {
     clear();
@@ -462,18 +463,7 @@ namespace Timbl {
     Error( "CVprepare called for NON CV experiment" );
     return false;
   }
-
-  ostream& operator<< ( ostream& os, const set<streamsize>& s ){
-    os << "{";
-    set<streamsize>::const_iterator it = s.begin();
-    while ( it != s.end() ){
-      os << *it << ",";
-      ++it;
-    }
-    os << "}";
-    return os;
-  }
-
+  
   ostream& operator<< ( ostream& os, const fileIndex& fi ){
     fileIndex::const_iterator it = fi.begin();
     while ( it != fi.end() ){
@@ -503,7 +493,7 @@ namespace Timbl {
 	  time_stamp( "Learning:  ", stats.dataLines() );
 	chopped_to_instance( TrainWords );
 	if ( !outInstanceBase )
-	  outInstanceBase =InstanceBase->clone();
+	  outInstanceBase = InstanceBase->clone();
 	//		  cerr << "add instance " << &CurrInst << endl;
 	if ( !outInstanceBase->AddInstance( CurrInst ) ){
 	  Warning( "deviating exemplar weight in:\n" + 
@@ -656,8 +646,7 @@ namespace Timbl {
       else {	
 	chopped_to_instance( TrainLearnWords );
 	MBL_init = false;
-	bool happy;
-	happy = InstanceBase->AddInstance( CurrInst );
+	bool happy = InstanceBase->AddInstance( CurrInst );
 	if ( !happy )
 	  Warning( "deviating exemplar weight in:\n" + 
 		   InstanceString + "\nIgnoring the new weight" );
@@ -740,8 +729,7 @@ namespace Timbl {
 	do {
 	  // The next Instance to store. 
 	  chopped_to_instance( TrainLearnWords );
-	  bool happy;
-	  happy = InstanceBase->AddInstance( CurrInst );
+	  bool happy = InstanceBase->AddInstance( CurrInst );
 	  if ( !happy ){
 	    Warning( "deviating exemplar weight in line #" + 
 		     toString<int>(stats.totalLines() ) + ":\n" +
@@ -851,6 +839,9 @@ namespace Timbl {
     case Columns:
       os << "InputFormat       : Columns";
       break;
+    case Tabbed:
+      os << "InputFormat       : Tabbed";
+      break;      
     case Compact:
       os << "InputFormat       : Compact, (Feature Length = "
 	 << F_length << ")";
@@ -1167,8 +1158,7 @@ namespace Timbl {
 	  while( go_on ){ 
 	    // The next Instance to store. 
 	    chopped_to_instance( TrainWords );
-	    bool happy;
-	    happy = InstanceBase->AddInstance( CurrInst );
+	    bool happy = InstanceBase->AddInstance( CurrInst );
 	    if ( !happy ){
 	      Warning( "deviating exemplar weight in line #" +
 		       toString<int>(stats.totalLines()) + ":\n" +
@@ -1308,8 +1298,7 @@ namespace Timbl {
 	    stats = stats_keep;
 	    if ( ResultTarget != CurrInst.TV ) {
 	      chopped_to_instance( TrainLearnWords );
-	      bool happy;
-	      happy = InstanceBase->AddInstance( CurrInst );
+	      bool happy = InstanceBase->AddInstance( CurrInst );
 	      if ( !happy ){
 		Warning( "deviating exemplar weight in line #" + 
 			 toString<int>(stats.totalLines() ) + ":\n" +
