@@ -1,8 +1,8 @@
 /*
-  $Id: neighborSet.cxx 13492 2011-10-31 11:48:46Z sloot $
+  $Id: neighborSet.cxx 15266 2012-10-10 11:00:27Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/neighborSet.cxx $
 
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -32,10 +32,8 @@
 #include <vector>
 
 #include "timbl/Common.h"
-#include "timbl/StringOps.h"
 #include "timbl/MsgClass.h"
 #include "timbl/Types.h"
-#include "timbl/Tree.h"
 #include "timbl/Instance.h"
 #include "timbl/neighborSet.h"
 
